pub fn server_info() -> ServerInfoExpand description
Returns the shared ServerInfo for all handler implementations.
Provides consistent server identity, capabilities, and instructions across all database backends.
pub fn server_info() -> ServerInfoReturns the shared ServerInfo for all handler implementations.
Provides consistent server identity, capabilities, and instructions across all database backends.